@@ -5,8 +5,9 @@ case "$CC" in
   "") CC=cc
 esac
 
-test -f config.h || echo "Creating basic config.h..." && \
-	cat >config.h <<'END_OF_CONFIG_H'
+if test -f config.h; then :; else
+  echo "Creating basic config.h..."
+  cat >config.h <<'END_OF_CONFIG_H'
 /* A bootstrap version of config.h, for systems which can't
    auto-configure due to a lack of a working sed.  If you are on
    a sufficiently odd machine you may need to hand-tweak this file.
@@ -33,6 +34,7 @@ test -f config.h || echo "Creating basic config.h..." && \
 /* All other config.h.in options intentionally omitted.  Report as a
    bug if you need extra "#define"s in here. */
 END_OF_CONFIG_H
+fi
 
 # tell the user what we're doing from here on...
 set -x
@@ -45,7 +47,7 @@ ${CC} -DHAVE_CONFIG_H -I.. -I. -c \
   alloca.c getopt.c getopt1.c memcmp.c memmove.c regex.c strerror.c || exit 1
 
 cd ../sed || exit 1
-${CC} -DHAVE_CONFIG_H -I.. -I. -I../lib -c \
+${CC} -DHAVE_CONFIG_H -I.. -I. -I../lib -DUSE_REGEX_GNU_H -c \
   sed.c compile.c execute.c utils.c || exit 1
 
 ${CC} -o sed sed.o compile.o execute.o utils.o ../lib/*.o || exit 1
